sv.blob-storage


BlobStoragecljprotocol

A protocol for storing binary large objects. The protocol tries to foster implementations, which treat blobs as immutable data.

A protocol for storing binary large objects. The protocol tries to
foster implementations, which treat blobs as immutable data.

deleteclj

(delete this id)

Deletes the data which is stored under the given UUID from the BlobStorage. Returns true, if the blob was found and deleted, otherwise false.

Deletes the data which is stored under the given UUID from the
BlobStorage. Returns true, if the blob was found and deleted,
otherwise false.

existsclj

(exists this id)

Returns true, if a blob with the given UUID exists in the BlobStorage.

Returns true, if a blob with the given UUID exists in the
BlobStorage.

retrieveclj

(retrieve this id)

Retrieves the data which is stored under the given UUID from the BlobStorage. Returns a java.io.InputStream with the data or nil, if a blob with the given UUID was not found.

Retrieves the data which is stored under the given UUID from the
BlobStorage. Returns a java.io.InputStream with the data or nil, if
a blob with the given UUID was not found.

storeclj

(store this in)

Stores the data from the InputStream in the BlobStorage and returns an UUID that must be used to retrieve the data again.

Stores the data from the InputStream in the BlobStorage and
returns an UUID that must be used to retrieve the data again.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries